package com.ruoyi.project.plant.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.poi.POIConstants;
import com.ruoyi.common.utils.poi.PoiWordTools;
import com.ruoyi.project.plant.domain.TMtActionlist;
import com.ruoyi.project.system.domain.SysDictData;
import org.apache.commons.collections.CollectionUtils;
import org.apache.poi.xwpf.usermodel.*;
import org.apache.xmlbeans.XmlCursor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.plant.mapper.TMtInterlockMapper;
import com.ruoyi.project.plant.domain.TMtInterlock;
import com.ruoyi.project.plant.service.ITMtInterlockService;

/**
 * 关键机组联锁旁路Service业务层处理
 *
 * @author ruoyi
 * @date 2021-01-05
 */
@Service
public class TMtInterlockServiceImpl implements ITMtInterlockService
{
    @Autowired
    private TMtInterlockMapper tMtInterlockMapper;

    /**
     * 查询关键机组联锁旁路
     *
     * @param id 关键机组联锁旁路ID
     * @return 关键机组联锁旁路
     */
    @Override
    public TMtInterlock selectTMtInterlockById(Long id)
    {
        return tMtInterlockMapper.selectTMtInterlockById(id);
    }

    /**
     * 查询关键机组联锁旁路列表
     *
     * @param tMtInterlock 关键机组联锁旁路
     * @return 关键机组联锁旁路
     */
    @Override
    public List<TMtInterlock> selectTMtInterlockList(TMtInterlock tMtInterlock)
    {
        return tMtInterlockMapper.selectTMtInterlockList(tMtInterlock);
    }

    /**
     * 新增关键机组联锁旁路
     *
     * @param tMtInterlock 关键机组联锁旁路
     * @return 结果
     */
    @Override
    public int insertTMtInterlock(TMtInterlock tMtInterlock)
    {
        return tMtInterlockMapper.insertTMtInterlock(tMtInterlock);
    }

    /**
     * 修改关键机组联锁旁路
     *
     * @param tMtInterlock 关键机组联锁旁路
     * @return 结果
     */
    @Override
    public int updateTMtInterlock(TMtInterlock tMtInterlock)
    {
        return tMtInterlockMapper.updateTMtInterlock(tMtInterlock);
    }

    /**
     * 批量删除关键机组联锁旁路
     *
     * @param ids 需要删除的关键机组联锁旁路ID
     * @return 结果
     */
    @Override
    public int deleteTMtInterlockByIds(Long[] ids)
    {
        return tMtInterlockMapper.deleteTMtInterlockByIds(ids);
    }

    /**
     * 删除关键机组联锁旁路信息
     *
     * @param id 关键机组联锁旁路ID
     * @return 结果
     */
    @Override
    public int deleteTMtInterlockById(Long id)
    {
        return tMtInterlockMapper.deleteTMtInterlockById(id);
    }

    @Override
    public void dealInterlock(XWPFDocument doc, XWPFParagraph paragraph, XWPFRun run, Long meetingId) {
        run.setText("", 0);//设置此文本在运行中的文本value -应在文件中显示的文字文本,pos --在文本数组中的位置（NB：从0开始）
        XmlCursor cursor = paragraph.getCTP().newCursor();
        XWPFTable tableOne = doc.insertNewTbl(cursor);// ---这个是关键

        // 设置表格宽度，第一行宽度就可以了，这个值的单位，目前我也还不清楚，还没来得及研究
        tableOne.setWidth(10000);

        // 表格第一行，对于每个列，必须使用createCell()，而不是getCell()，因为第一行嘛，肯定是属于创建的，没有create哪里来的get呢
        XWPFTableRow tableOneRowOne = tableOne.getRow(0);// 行
        PoiWordTools.setWordCellSelfStyle(tableOneRowOne.getCell(0), POIConstants.FONT_NAME, POIConstants.MT_FONT_SIZE,  POIConstants.FONT_BOLD_C, POIConstants.ALIGNMENT,POIConstants.VERTICAL, POIConstants.FONT_COLOR, POIConstants.MT_BG_TITLE_COLOR, "60", "                      主要内容                      ");
        TMtInterlock tMtActionlist = new TMtInterlock();
        tMtActionlist.setMeetingId(meetingId);
        List<TMtInterlock> list = tMtInterlockMapper.selectTMtInterlockList(tMtActionlist);

        if (CollectionUtils.isNotEmpty(list)) {
            for (int i = 0; i < list.size(); i++) {
                String fontColor = POIConstants.FONT_COLOR;
                if (list.get(i).getIsNew() == 1l) {
                    fontColor = POIConstants.FONT_COLOR_BLUE;
                }
                // 表格第二行
                XWPFTableRow tableOneRowTwo = tableOne.createRow();// 行
                PoiWordTools.setWordCellSelfStyle(tableOneRowTwo.getCell(0), POIConstants.FONT_NAME, POIConstants.MT_FONT_SIZE, POIConstants.FONT_BOLD, POIConstants.ALIGNMENT,POIConstants.VERTICAL, fontColor, POIConstants.BG_COLOR, "40", list.get(i).getMaincontents());
            }
        }
    }
}
